@@ -1,13 +1,13 @@
 package Email::Sender::Transport::Mbox;
 # ABSTRACT: deliver mail to an mbox on disk
-$Email::Sender::Transport::Mbox::VERSION = '1.300014';
+$Email::Sender::Transport::Mbox::VERSION = '1.300018';
 use Moo;
 with 'Email::Sender::Transport';
 
 use Carp;
 use File::Path;
 use File::Basename;
-use IO::File;
+use IO::File 1.11; # binmode
 use Email::Simple 1.998;  # needed for ->header_obj
 use Fcntl ':flock';
 
@@ -126,7 +126,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 1.300014
+version 1.300018
 
 =head1 DESCRIPTION
 
@@ -142,7 +142,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
